@@ -1,5 +1,5 @@
 /******************************************************************************\
- * Copyright (c) 2004-2022
+ * Copyright (c) 2004-2024
  *
  * Author(s):
  *  Volker Fischer
@@ -114,7 +114,7 @@ CClientSettingsDlg::CClientSettingsDlg ( CClient* pNCliP, CClientSettings* pNSet
     sldNetBufServer->setWhatsThis ( strJitterBufferSize );
     sldNetBufServer->setAccessibleName ( tr ( "Server jitter buffer slider control" ) );
     sldNetBufServer->setToolTip ( strJitterBufferSizeTT );
-    chbAutoJitBuf->setAccessibleName ( tr ( "Auto jitter buffer switch" ) );
+    chbAutoJitBuf->setAccessibleName ( tr ( "Auto jitter buffer check box" ) );
     chbAutoJitBuf->setToolTip ( strJitterBufferSizeTT );
 
 #if !defined( WITH_JACK )
@@ -169,14 +169,15 @@ CClientSettingsDlg::CClientSettingsDlg ( CClient* pNCliP, CClientSettings* pNSet
 #endif
 
     // enable OPUS64
-    chbEnableOPUS64->setWhatsThis ( "<b>" + tr ( "Enable Small Network Buffers" ) + ":</b> " +
-                                    tr ( "Enables support for very small network audio packets. These "
-                                         "network packets are only actually used if the sound card buffer delay is smaller than %1 samples. The "
-                                         "smaller the network buffers, the lower the audio latency. But at the same time "
-                                         "the network load and the probability of audio dropouts or sound artifacts increases." )
-                                        .arg ( DOUBLE_SYSTEM_FRAME_SIZE_SAMPLES ) );
+    chbSmallNetworkBuffers->setWhatsThis (
+        "<b>" + tr ( "Small Network Buffers" ) + ":</b> " +
+        tr ( "Enables support for very small network audio packets. These "
+             "network packets are only actually used if the sound card buffer delay is smaller than %1 samples. The "
+             "smaller the network buffers, the lower the audio latency. But at the same time "
+             "the network load and the probability of audio dropouts or sound artifacts increases." )
+            .arg ( DOUBLE_SYSTEM_FRAME_SIZE_SAMPLES ) );
 
-    chbEnableOPUS64->setAccessibleName ( tr ( "Enable small network buffers check box" ) );
+    chbSmallNetworkBuffers->setAccessibleName ( tr ( "Small network buffers check box" ) );
 
     // sound card buffer delay
     QString strSndCrdBufDelay =
@@ -359,14 +360,17 @@ CClientSettingsDlg::CClientSettingsDlg ( CClient* pNCliP, CClientSettings* pNSet
     // custom directories
     QString strCustomDirectories = "<b>" + tr ( "Custom Directories" ) + ":</b> " +
                                    tr ( "If you need to add additional directories to the Connect dialog Directory drop down, "
-                                        "you can enter the addresses here.<br>"
-                                        "To remove a value, select it, delete the text in the input box, "
-                                        "then move focus out of the control." );
+                                        "you can enter the addresses here.<br>" );
 
     lblCustomDirectories->setWhatsThis ( strCustomDirectories );
     cbxCustomDirectories->setWhatsThis ( strCustomDirectories );
     cbxCustomDirectories->setAccessibleName ( tr ( "Custom Directories combo box" ) );
 
+    tbtDeleteCustomDirectory->setAccessibleName ( tr ( "Delete custom directory button" ) );
+    tbtDeleteCustomDirectory->setWhatsThis ( "<b>" + tr ( "Delete Custom Directory" ) + ":</b> " +
+                                             tr ( "Click the button to delete the currently selected custom directory." ) );
+    tbtDeleteCustomDirectory->setText ( u8"\u232B" );
+
     // current connection status parameter
     QString strConnStats = "<b>" + tr ( "Audio Upstream Rate" ) + ":</b> " +
                            tr ( "Depends on the current audio packet size and "
@@ -383,19 +387,14 @@ CClientSettingsDlg::CClientSettingsDlg ( CClient* pNCliP, CClientSettings* pNSet
     spnMixerRows->setWhatsThis ( strNumMixerPanelRows );
     spnMixerRows->setAccessibleName ( tr ( "Number of Mixer Panel Rows spin box" ) );
 
-    QString strDetectFeedback = "<b>" + tr ( "Feedback Protection" ) + ":</b> " +
-                                tr ( "Enable feedback protection to detect acoustic feedback between "
-                                     "microphone and speakers." );
-    lblDetectFeedback->setWhatsThis ( strDetectFeedback );
-    chbDetectFeedback->setWhatsThis ( strDetectFeedback );
+    chbDetectFeedback->setWhatsThis ( "<b>" + tr ( "Feedback Protection" ) + ":</b> " +
+                                      tr ( "Prevents acoustic feedback between microphone and speakers." ) );
     chbDetectFeedback->setAccessibleName ( tr ( "Feedback Protection check box" ) );
 
     // audio alerts
-    QString strAudioAlerts = "<b>" + tr ( "Audio Alerts" ) + ":</b> " +
-                             tr ( "Enable audio alert when receiving a chat message and when a new client joins the session. "
-                                  "A second sound device may be required to hear the alerts." );
-    lblAudioAlerts->setWhatsThis ( strAudioAlerts );
-    chbAudioAlerts->setWhatsThis ( strAudioAlerts );
+    chbAudioAlerts->setWhatsThis ( "<b>" + tr ( "Audio Alerts" ) + ":</b> " +
+                                   tr ( "Trigger an audio alert when receiving a chat message and when a new client joins the session. "
+                                        "A second sound device may be required to hear the alerts." ) );
     chbAudioAlerts->setAccessibleName ( tr ( "Audio Alerts check box" ) );
 
     // init driver button
@@ -485,7 +484,7 @@ CClientSettingsDlg::CClientSettingsDlg ( CClient* pNCliP, CClientSettings* pNSet
     chbDetectFeedback->setCheckState ( pSettings->bEnableFeedbackDetection ? Qt::Checked : Qt::Unchecked );
 
     // update enable small network buffers check box
-    chbEnableOPUS64->setCheckState ( pClient->GetEnableOPUS64() ? Qt::Checked : Qt::Unchecked );
+    chbSmallNetworkBuffers->setCheckState ( pClient->GetEnableOPUS64() ? Qt::Checked : Qt::Unchecked );
 
     // set text for sound card buffer delay radio buttons
     rbtBufferDelayPreferred->setText ( GenSndCrdBufferDelayString ( FRAME_SIZE_FACTOR_PREFERRED * SYSTEM_FRAME_SIZE_SAMPLES ) );
@@ -640,7 +639,7 @@ CClientSettingsDlg::CClientSettingsDlg ( CClient* pNCliP, CClientSettings* pNSet
     // check boxes
     QObject::connect ( chbAutoJitBuf, &QCheckBox::stateChanged, this, &CClientSettingsDlg::OnAutoJitBufStateChanged );
 
-    QObject::connect ( chbEnableOPUS64, &QCheckBox::stateChanged, this, &CClientSettingsDlg::OnEnableOPUS64StateChanged );
+    QObject::connect ( chbSmallNetworkBuffers, &QCheckBox::stateChanged, this, &CClientSettingsDlg::OnEnableOPUS64StateChanged );
 
     QObject::connect ( chbDetectFeedback, &QCheckBox::stateChanged, this, &CClientSettingsDlg::OnFeedbackDetectionChanged );
 
@@ -695,12 +694,9 @@ CClientSettingsDlg::CClientSettingsDlg ( CClient* pNCliP, CClientSettings* pNSet
                        this,
                        &CClientSettingsDlg::OnMeterStyleActivated );
 
-    QObject::connect ( cbxCustomDirectories->lineEdit(), &QLineEdit::editingFinished, this, &CClientSettingsDlg::OnCustomDirectoriesEditingFinished );
-
-    QObject::connect ( cbxCustomDirectories,
-                       static_cast<void ( QComboBox::* ) ( int )> ( &QComboBox::activated ),
-                       this,
-                       &CClientSettingsDlg::OnCustomDirectoriesEditingFinished );
+    QObject::connect ( cbxCustomDirectories->lineEdit(), &QLineEdit::editingFinished, this, [this] {
+        CClientSettingsDlg::OnCustomDirectoriesChanged ( false );
+    } );
 
     QObject::connect ( cbxLanguage, &CLanguageComboBox::LanguageChanged, this, &CClientSettingsDlg::OnLanguageChanged );
 
@@ -715,6 +711,9 @@ CClientSettingsDlg::CClientSettingsDlg ( CClient* pNCliP, CClientSettings* pNSet
     QObject::connect ( butDriverSetup, &QPushButton::clicked, this, &CClientSettingsDlg::OnDriverSetupClicked );
 #endif
 
+    // tool buttons
+    QObject::connect ( tbtDeleteCustomDirectory, &QToolButton::clicked, this, [this] { CClientSettingsDlg::OnCustomDirectoriesChanged ( true ); } );
+
     // misc
     // sliders
     QObject::connect ( sldAudioPan, &QSlider::valueChanged, this, &CClientSettingsDlg::OnAudioPanValueChanged );
@@ -759,7 +758,7 @@ CClientSettingsDlg::CClientSettingsDlg ( CClient* pNCliP, CClientSettings* pNSet
 void CClientSettingsDlg::showEvent ( QShowEvent* )
 {
     UpdateDisplay();
-    UpdateDirectoryServerComboBox();
+    UpdateDirectoryComboBox();
 
     // set the name
     pedtAlias->setText ( pClient->ChannelInfo.strName );
@@ -1013,31 +1012,34 @@ void CClientSettingsDlg::OnEnableOPUS64StateChanged ( int value )
 
 void CClientSettingsDlg::OnFeedbackDetectionChanged ( int value ) { pSettings->bEnableFeedbackDetection = value == Qt::Checked; }
 
-void CClientSettingsDlg::OnCustomDirectoriesEditingFinished()
+void CClientSettingsDlg::OnCustomDirectoriesChanged ( bool bDelete )
 {
-    if ( cbxCustomDirectories->currentText().isEmpty() && cbxCustomDirectories->currentData().isValid() )
+    if ( bDelete )
     {
-        // if the user has selected an entry in the combo box list and deleted the text in the input field,
-        // and then focus moves off the control without selecting a new entry,
-        // we delete the corresponding entry in the vector
-        pSettings->vstrDirectoryAddress[cbxCustomDirectories->currentData().toInt()] = "";
-    }
-    else if ( cbxCustomDirectories->currentData().isValid() && pSettings->vstrDirectoryAddress[cbxCustomDirectories->currentData().toInt()].compare (
-                                                                   NetworkUtil::FixAddress ( cbxCustomDirectories->currentText() ) ) == 0 )
-    {
-        // if the user has selected another entry in the combo box list without changing anything,
-        // there is no need to update any list
-        return;
+        if ( !cbxCustomDirectories->currentData().isValid() )
+        {
+            // no selected directory to delete
+            return;
+        }
+        // delete the selected directory
+        pSettings->vstrDirectoryAddress[cbxCustomDirectories->currentData().toInt()] = QString();
     }
     else
     {
+
+        if ( cbxCustomDirectories->currentText().isEmpty() ||
+             ( cbxCustomDirectories->currentData().isValid() && pSettings->vstrDirectoryAddress[cbxCustomDirectories->currentData().toInt()].compare (
+                                                                    NetworkUtil::FixAddress ( cbxCustomDirectories->currentText() ) ) == 0 ) )
+        {
+            // no need to add a already added directory
+            return;
+        }
         // store new address at the top of the list, if the list was already
         // full, the last element is thrown out
         pSettings->vstrDirectoryAddress.StringFiFoWithCompare ( NetworkUtil::FixAddress ( cbxCustomDirectories->currentText() ) );
     }
-
     // update combo box list and inform connect dialog about the new address
-    UpdateDirectoryServerComboBox();
+    UpdateDirectoryComboBox();
     emit CustomDirectoriesChanged();
 }
 
@@ -1082,7 +1084,7 @@ void CClientSettingsDlg::UpdateDisplay()
     }
 }
 
-void CClientSettingsDlg::UpdateDirectoryServerComboBox()
+void CClientSettingsDlg::UpdateDirectoryComboBox()
 {
     cbxCustomDirectories->clear();
     cbxCustomDirectories->clearEditText();
