@@ -1,5 +1,5 @@
 /******************************************************************************\
- * Copyright (c) 2004-2022
+ * Copyright (c) 2004-2024
  *
  * Author(s):
  *  Volker Fischer
@@ -42,7 +42,7 @@
 #ifdef ANDROID
 #    include <QtAndroidExtras/QtAndroid>
 #endif
-#if defined( Q_OS_MACX )
+#if defined( Q_OS_MACOS )
 #    include "mac/activity.h"
 extern void qt_set_sequence_auto_mnemonic ( bool bEnable );
 #endif
@@ -60,7 +60,7 @@ extern void qt_set_sequence_auto_mnemonic ( bool bEnable );
 int main ( int argc, char** argv )
 {
 
-#if defined( Q_OS_MACX )
+#if defined( Q_OS_MACOS )
     // Mnemonic keys are default disabled in Qt for MacOS. The following function enables them.
     // Qt will not show these with underline characters in the GUI on MacOS. (#1873)
     qt_set_sequence_auto_mnemonic ( true );
@@ -74,7 +74,7 @@ int main ( int argc, char** argv )
 
     // initialize all flags and string which might be changed by command line
     // arguments
-#if ( defined( SERVER_BUNDLE ) && defined( Q_OS_MACX ) ) || defined( SERVER_ONLY )
+#if ( defined( SERVER_BUNDLE ) && defined( Q_OS_MACOS ) ) || defined( SERVER_ONLY )
     // if we are on MacOS and we are building a server bundle or requested build with serveronly, start Jamulus in server mode
     bool bIsClient = false;
     qInfo() << "- Starting in server mode by default (due to compile time option)";
@@ -99,6 +99,7 @@ int main ( int argc, char** argv )
     int          iNumServerChannels          = DEFAULT_USED_NUM_CHANNELS;
     quint16      iPortNumber                 = DEFAULT_PORT_NUMBER;
     int          iJsonRpcPortNumber          = INVALID_PORT;
+    QString      strJsonRpcBindIP            = DEFAULT_JSON_RPC_LISTEN_ADDRESS;
     quint16      iQosNumber                  = DEFAULT_QOS_NUMBER;
     ELicenceType eLicenceType                = LT_NO_LICENCE;
     QString      strMIDISetup                = "";
@@ -107,7 +108,7 @@ int main ( int argc, char** argv )
     QString      strHTMLStatusFileName       = "";
     QString      strLoggingFileName          = "";
     QString      strRecordingDirName         = "";
-    QString      strDirectoryServer          = "";
+    QString      strDirectoryAddress         = "";
     QString      strServerListFileName       = "";
     QString      strServerInfo               = "";
     QString      strServerPublicIP           = "";
@@ -209,6 +210,15 @@ int main ( int argc, char** argv )
             continue;
         }
 
+        // JSON-RPC bind address ------------------------------------------------
+        if ( GetStringArgument ( argc, argv, i, "--jsonrpcbindip", "--jsonrpcbindip", strArgument ) )
+        {
+            strJsonRpcBindIP = QString ( strArgument );
+            qInfo() << qUtf8Printable ( QString ( "- JSON-RPC will bind to: %1 if enabled" ).arg ( strJsonRpcBindIP ) );
+            CommandLineOptions << "--jsonrpcbindip";
+            continue;
+        }
+
         // Quality of Service --------------------------------------------------
         if ( GetNumericArgument ( argc, argv, i, "-Q", "--qos", 0, 255, rDbleArgument ) )
         {
@@ -248,13 +258,13 @@ int main ( int argc, char** argv )
             continue;
         }
 
-        // Directory server ----------------------------------------------------
-        if ( GetStringArgument ( argc, argv, i, "-e", "--directoryserver", strArgument ) )
+        // Directory to register with ------------------------------------------
+        if ( GetStringArgument ( argc, argv, i, "-e", "--directoryaddress", strArgument ) )
         {
-            strDirectoryServer = strArgument;
-            qInfo() << qUtf8Printable ( QString ( "- directory server: %1" ).arg ( strDirectoryServer ) );
-            CommandLineOptions << "--directoryserver";
-            ServerOnlyOptions << "--directoryserver";
+            strDirectoryAddress = strArgument;
+            qInfo() << qUtf8Printable ( QString ( "- register with directory at address: %1" ).arg ( strDirectoryAddress ) );
+            CommandLineOptions << "--directoryaddress";
+            ServerOnlyOptions << "--directoryaddress";
             continue;
         }
 
@@ -262,14 +272,14 @@ int main ( int argc, char** argv )
         if ( GetStringArgument ( argc,
                                  argv,
                                  i,
-                                 "--centralserver", // no short form
-                                 "--centralserver",
+                                 "--centralserver",   // for backwards compatibility
+                                 "--directoryserver", // also for backwards compatibility
                                  strArgument ) )
         {
-            strDirectoryServer = strArgument;
-            qInfo() << qUtf8Printable ( QString ( "- directory server: %1" ).arg ( strDirectoryServer ) );
-            CommandLineOptions << "--directoryserver";
-            ServerOnlyOptions << "--directoryserver";
+            strDirectoryAddress = strArgument;
+            qInfo() << qUtf8Printable ( QString ( "- register with directory at address: %1" ).arg ( strDirectoryAddress ) );
+            CommandLineOptions << "--directoryaddress";
+            ServerOnlyOptions << "--directoryaddress";
             continue;
         }
 
@@ -282,7 +292,7 @@ int main ( int argc, char** argv )
                                  strArgument ) )
         {
             strServerListFileName = strArgument;
-            qInfo() << qUtf8Printable ( QString ( "- directory server persistence file: %1" ).arg ( strServerListFileName ) );
+            qInfo() << qUtf8Printable ( QString ( "- server list persistence file: %1" ).arg ( strServerListFileName ) );
             CommandLineOptions << "--directoryfile";
             ServerOnlyOptions << "--directoryfile";
             continue;
@@ -436,9 +446,7 @@ int main ( int argc, char** argv )
         if ( GetNumericArgument ( argc, argv, i, "-u", "--numchannels", 1, MAX_NUM_CHANNELS, rDbleArgument ) )
         {
             iNumServerChannels = static_cast<int> ( rDbleArgument );
-
             qInfo() << qUtf8Printable ( QString ( "- maximum number of channels: %1" ).arg ( iNumServerChannels ) );
-
             CommandLineOptions << "--numchannels";
             ServerOnlyOptions << "--numchannels";
             continue;
@@ -572,26 +580,12 @@ int main ( int argc, char** argv )
             continue;
         }
 
-        // Clean up legacy fader settings --------------------------------------
-        // Undocumented temporary command line argument: Clean up fader settings
-        // corrupted by bug #2680.  Only needs to be used once (per file).
-        if ( GetFlagArgument ( argv,
-                               i,
-                               "--cleanuplegacyfadersettings", // no short form
-                               "--cleanuplegacyfadersettings" ) )
-        {
-            qInfo() << "- will clean up legacy fader settings on load";
-            CommandLineOptions << "--cleanuplegacyfadersettings";
-            ClientOnlyOptions << "--cleanuplegacyfadersettings";
-            continue;
-        }
-
         // Unknown option ------------------------------------------------------
         qCritical() << qUtf8Printable ( QString ( "%1: Unknown option '%2' -- use '--help' for help" ).arg ( argv[0] ).arg ( argv[i] ) );
 
 // clicking on the Mac application bundle, the actual application
 // is called with weird command line args -> do not exit on these
-#if !( defined( Q_OS_MACX ) )
+#if !( defined( Q_OS_MACOS ) )
         exit ( 1 );
 #endif
     }
@@ -603,20 +597,19 @@ int main ( int argc, char** argv )
         bUseGUI = false;
         qWarning() << "No GUI support compiled. Running in headless mode.";
     }
-#endif
 
-    if ( bIsClient )
+#endif
 #ifdef SERVER_ONLY
+    if ( bIsClient )
     {
         qCritical() << "Only --server mode is supported in this build.";
         exit ( 1 );
     }
+
 #else
-
-    // TODO create settings in default state, if loading from file do that next, then come back here to
-    //      override from command line options, then create client or server, letting them do the validation
-
+    if ( bIsClient )
     {
+
         if ( ServerOnlyOptions.size() != 0 )
         {
             qCritical() << qUtf8Printable ( QString ( "%1: Server only option(s) '%2' used.  Did you omit '--server'?" )
@@ -643,6 +636,7 @@ int main ( int argc, char** argv )
     else
 #endif
     {
+
         if ( ClientOnlyOptions.size() != 0 )
         {
             qCritical() << qUtf8Printable (
@@ -650,6 +644,13 @@ int main ( int argc, char** argv )
             exit ( 1 );
         }
 
+        if ( ServerOnlyOptions.contains ( "--serverinfo" ) && strServerInfo.split ( ";" ).count() < 3 )
+        {
+            qWarning() << qUtf8Printable (
+                QString ( "\"--serverinfo '%1'\": must contain [name];[city];[country] - value will be ignored" ).arg ( strServerInfo ) );
+            strServerInfo = "";
+        }
+
 #ifndef HEADLESS
         if ( bUseGUI )
         {
@@ -659,13 +660,13 @@ int main ( int argc, char** argv )
             if ( !strServerListFileName.isEmpty() )
             {
                 qInfo() << "Note:"
-                        << "Server list persistence file will only take effect when running as a directory server.";
+                        << "Server list persistence file will only take effect when running as a directory.";
             }
 
             if ( !strServerListFilter.isEmpty() )
             {
                 qInfo() << "Note:"
-                        << "Server list filter will only take effect when running as a directory server.";
+                        << "Server list filter will only take effect when running as a directory.";
             }
         }
         else
@@ -679,7 +680,7 @@ int main ( int argc, char** argv )
             }
             // therefore we know everything based on command line options
 
-            if ( strDirectoryServer.compare ( "localhost", Qt::CaseInsensitive ) == 0 || strDirectoryServer.compare ( "127.0.0.1" ) == 0 )
+            if ( strDirectoryAddress.compare ( "localhost", Qt::CaseInsensitive ) == 0 || strDirectoryAddress.compare ( "127.0.0.1" ) == 0 )
             {
                 if ( !strServerListFileName.isEmpty() )
                 {
@@ -741,22 +742,22 @@ int main ( int argc, char** argv )
             {
                 if ( !strServerListFileName.isEmpty() )
                 {
-                    qWarning() << "Server list persistence file will only take effect when running as a directory server.";
+                    qWarning() << "Server list persistence file will only take effect when running as a directory.";
                     strServerListFileName = "";
                 }
 
                 if ( !strServerListFilter.isEmpty() )
                 {
-                    qWarning() << "Server list filter will only take effect when running as a directory server.";
+                    qWarning() << "Server list filter will only take effect when running as a directory.";
                     strServerListFileName = "";
                 }
             }
 
-            if ( strDirectoryServer.isEmpty() )
+            if ( strDirectoryAddress.isEmpty() )
             {
                 if ( !strServerPublicIP.isEmpty() )
                 {
-                    qWarning() << "Server Public IP will only take effect when registering a server with a directory server.";
+                    qWarning() << "Server Public IP will only take effect when registering a server with a directory.";
                     strServerPublicIP = "";
                 }
             }
@@ -783,6 +784,28 @@ int main ( int argc, char** argv )
                 strServerBindIP = "";
             }
         }
+#ifndef NO_JSON_RPC
+
+        // strJsonRpcBind address defaults to loopback and should not be empty, but
+        // in the odd chance that an empty IP is passed, we'll check for it here.
+        if ( strJsonRpcBindIP.trimmed().isEmpty() )
+        {
+            qCritical() << qUtf8Printable ( QString ( "JSON-RPC is enabled but the bind address provided is empty, exiting." ) );
+            exit ( 1 );
+        }
+
+        // This means of testing the validity of IP addresses is far from perfect but
+        // we do it here as an upfront check.  The downstream network calls will error
+        // out on malformed addresses not caught here.
+        {
+            QHostAddress InetAddr;
+            if ( !InetAddr.setAddress ( strJsonRpcBindIP ) )
+            {
+                qCritical() << qUtf8Printable ( QString ( "The JSON-RPC address specified is not valid, exiting. " ) );
+                exit ( 1 );
+            }
+        }
+#endif
     }
 
     // Application/GUI setup ---------------------------------------------------
@@ -827,7 +850,7 @@ int main ( int argc, char** argv )
     pApp->addLibraryPath ( QString ( ApplDir.absolutePath() ) );
 #endif
 
-#if defined( Q_OS_MACX )
+#if defined( Q_OS_MACOS )
     // On OSX we need to declare an activity to ensure the process doesn't get
     // throttled by OS level Nap, Sleep, and Thread Priority systems.
     CActivity activity;
@@ -880,7 +903,7 @@ int main ( int argc, char** argv )
         qWarning() << "- JSON-RPC: This interface is experimental and is subject to breaking changes even on patch versions "
                       "(not subject to semantic versioning) during the initial phase.";
 
-        pRpcServer = new CRpcServer ( pApp, iJsonRpcPortNumber, strJsonRpcSecret );
+        pRpcServer = new CRpcServer ( pApp, strJsonRpcBindIP, iJsonRpcPortNumber, strJsonRpcSecret );
         if ( !pRpcServer->Start() )
         {
             qCritical() << qUtf8Printable ( QString ( "- JSON-RPC: Server failed to start. Exiting." ) );
@@ -909,13 +932,6 @@ int main ( int argc, char** argv )
             CClientSettings Settings ( &Client, strIniFileName );
             Settings.Load ( CommandLineOptions );
 
-            // load translation
-            if ( bUseGUI && bUseTranslation )
-            {
-                CLocale::LoadTranslation ( Settings.strLanguage, pApp );
-                CInstPictures::UpdateTableOnLanguageChange();
-            }
-
 #    ifndef NO_JSON_RPC
             if ( pRpcServer )
             {
@@ -926,6 +942,13 @@ int main ( int argc, char** argv )
 #    ifndef HEADLESS
             if ( bUseGUI )
             {
+                // load translation
+                if ( bUseTranslation )
+                {
+                    CLocale::LoadTranslation ( Settings.strLanguage, pApp );
+                    CInstPictures::UpdateTableOnLanguageChange();
+                }
+
                 // GUI object
                 CClientDlg ClientDlg ( &Client,
                                        &Settings,
@@ -939,6 +962,7 @@ int main ( int argc, char** argv )
 
                 // show dialog
                 ClientDlg.show();
+
                 pApp->exec();
             }
             else
@@ -961,7 +985,7 @@ int main ( int argc, char** argv )
                              iPortNumber,
                              iQosNumber,
                              strHTMLStatusFileName,
-                             strDirectoryServer,
+                             strDirectoryAddress,
                              strServerListFileName,
                              strServerInfo,
                              strServerPublicIP,
@@ -981,8 +1005,8 @@ int main ( int argc, char** argv )
             {
                 new CServerRpc ( &Server, pRpcServer, pRpcServer );
             }
-#endif
 
+#endif
 #ifndef HEADLESS
             if ( bUseGUI )
             {
@@ -991,7 +1015,7 @@ int main ( int argc, char** argv )
                 Settings.Load ( CommandLineOptions );
 
                 // load translation
-                if ( bUseGUI && bUseTranslation )
+                if ( bUseTranslation )
                 {
                     CLocale::LoadTranslation ( Settings.strLanguage, pApp );
                 }
@@ -1014,8 +1038,8 @@ int main ( int argc, char** argv )
                 qInfo() << qUtf8Printable ( GetVersionAndNameStr ( false ) );
 
                 // CServerListManager defaults to AT_NONE, so need to switch if
-                // strDirectoryServer is wanted
-                if ( !strDirectoryServer.isEmpty() )
+                // strDirectoryAddress is wanted
+                if ( !strDirectoryAddress.isEmpty() )
                 {
                     Server.SetDirectoryType ( AT_CUSTOM );
                 }
@@ -1041,7 +1065,7 @@ int main ( int argc, char** argv )
         }
     }
 
-#if defined( Q_OS_MACX )
+#if defined( Q_OS_MACOS )
     activity.EndActivity();
 #endif
 
@@ -1058,60 +1082,60 @@ QString UsageArguments ( char** argv )
            "\n"
            "Usage: %1 [option] [option argument] ...\n"
            "\n"
-           "  -h, -?, --help        display this help text and exit\n"
-           "  -v, --version         display version information and exit\n"
+           "  -h, -?, --help          display this help text and exit\n"
+           "  -v, --version           display version information and exit\n"
            "\n"
            "Common options:\n"
-           "  -i, --inifile         initialization file name\n"
-           "                        (not supported for headless Server mode)\n"
-           "  -n, --nogui           disable GUI (\"headless\")\n"
-           "  -p, --port            set the local port number\n"
-           "      --jsonrpcport     enable JSON-RPC server, set TCP port number\n"
-           "                        (EXPERIMENTAL, APIs might still change;\n"
-           "                        only accessible from localhost)\n"
-           "      --jsonrpcsecretfile\n"
-           "                        path to a single-line file which contains a freely\n"
-           "                        chosen secret to authenticate JSON-RPC users.\n"
-           "  -Q, --qos             set the QoS value. Default is 128. Disable with 0\n"
-           "                        (see the Jamulus website to enable QoS on Windows)\n"
-           "  -t, --notranslation   disable translation (use English language)\n"
-           "  -6, --enableipv6      enable IPv6 addressing (IPv4 is always enabled)\n"
+           "  -i, --inifile           initialization file name\n"
+           "                          (not supported for headless Server mode)\n"
+           "  -n, --nogui             disable GUI (\"headless\")\n"
+           "  -p, --port              set the local port number\n"
+           "      --jsonrpcport       enable JSON-RPC server, set TCP port number\n"
+           "                          (EXPERIMENTAL, APIs might still change;\n"
+           "                          only accessible from localhost)\n"
+           "      --jsonrpcsecretfile path to a single-line file which contains a freely\n"
+           "                          chosen secret to authenticate JSON-RPC users.\n"
+           "      --jsonrpcbindip     optional network address to bind RPC server. Defaults to 127.0.0.1.\n"
+           "  -Q, --qos               set the QoS value. Default is 128. Disable with 0\n"
+           "                          (see the Jamulus website to enable QoS on Windows)\n"
+           "  -t, --notranslation     disable translation (use English language)\n"
+           "  -6, --enableipv6        enable IPv6 addressing (IPv4 is always enabled)\n"
            "\n"
            "Server only:\n"
-           "  -d, --discononquit    disconnect all Clients on quit\n"
-           "  -e, --directoryserver address of the directory Server with which to register\n"
-           "                        (or 'localhost' to host a server list on this Server)\n"
-           "      --directoryfile   Remember registered Servers even if the Directory is restarted. Directory Servers only.\n"
-           "  -f, --listfilter      Server list whitelist filter.  Format:\n"
-           "                        [IP address 1];[IP address 2];[IP address 3]; ...\n"
-           "  -F, --fastupdate      use 64 samples frame size mode\n"
-           "  -l, --log             enable logging, set file name\n"
-           "  -L, --licence         show an agreement window before users can connect\n"
-           "  -m, --htmlstatus      enable HTML status file, set file name\n"
-           "  -o, --serverinfo      registration info for this Server.  Format:\n"
-           "                        [name];[city];[country as two-letter ISO country code or Qt5 QLocale ID]\n"
-           "      --serverpublicip  public IP address for this Server.  Needed when\n"
-           "                        registering with a server list hosted\n"
-           "                        behind the same NAT\n"
-           "  -P, --delaypan        start with delay panning enabled\n"
-           "  -R, --recording       set server recording directory; server will record when a session is active by default\n"
-           "      --norecord        set server not to record by default when recording is configured\n"
-           "  -s, --server          start Server\n"
-           "      --serverbindip    IP address the Server will bind to (rather than all)\n"
-           "  -T, --multithreading  use multithreading to make better use of\n"
-           "                        multi-core CPUs and support more Clients\n"
-           "  -u, --numchannels     maximum number of channels\n"
-           "  -w, --welcomemessage  welcome message to display on connect\n"
-           "                        (string or filename, HTML supported)\n"
-           "  -z, --startminimized  start minimizied\n"
+           "  -d, --discononquit      disconnect all Clients on quit\n"
+           "  -e, --directoryaddress  address of the Directory with which to register\n"
+           "                          (or 'localhost' to run as a Directory)\n"
+           "      --directoryfile     File to hold server list across Directory restarts. Directories only.\n"
+           "  -f, --listfilter        Server list whitelist filter. Directories only. Format:\n"
+           "                          [IP address 1];[IP address 2];[IP address 3]; ...\n"
+           "  -F, --fastupdate        use 64 samples frame size mode\n"
+           "  -l, --log               enable logging, set file name\n"
+           "  -L, --licence           show an agreement window before users can connect\n"
+           "  -m, --htmlstatus        enable HTML status file, set file name\n"
+           "  -o, --serverinfo        registration info for this Server.  Format:\n"
+           "                          [name];[city];[country as two-letter ISO country code or Qt5 QLocale ID]\n"
+           "      --serverpublicip    public IP address for this Server.  Needed when\n"
+           "                          registering with a server list hosted\n"
+           "                          behind the same NAT\n"
+           "  -P, --delaypan          start with delay panning enabled\n"
+           "  -R, --recording         set server recording directory; server will record when a session is active by default\n"
+           "      --norecord          set server not to record by default when recording is configured\n"
+           "  -s, --server            start Server\n"
+           "      --serverbindip      IP address the Server will bind to (rather than all)\n"
+           "  -T, --multithreading    use multithreading to make better use of\n"
+           "                          multi-core CPUs and support more Clients\n"
+           "  -u, --numchannels       maximum number of channels\n"
+           "  -w, --welcomemessage    welcome message to display on connect\n"
+           "                          (string or filename, HTML supported)\n"
+           "  -z, --startminimized    start minimizied\n"
            "\n"
            "Client only:\n"
-           "  -c, --connect         connect to given Server address on startup\n"
-           "  -j, --nojackconnect   disable auto JACK connections\n"
-           "  -M, --mutestream      prevent others on a server from hearing what I play\n"
-           "      --mutemyown       prevent me from hearing what I play in the server mix (headless only)\n"
-           "      --clientname      Client name (window title and JACK client name)\n"
-           "      --ctrlmidich      MIDI controller channel to listen\n"
+           "  -c, --connect           connect to given Server address on startup\n"
+           "  -j, --nojackconnect     disable auto JACK connections\n"
+           "  -M, --mutestream        prevent others on a server from hearing what I play\n"
+           "      --mutemyown         prevent me from hearing what I play in the server mix (headless only)\n"
+           "      --clientname        client name (window title and JACK client name)\n"
+           "      --ctrlmidich        configure MIDI controller\n"
            "\n"
            "Example: %1 -s --inifile myinifile.ini\n"
            "\n"
