@@ -1,5 +1,5 @@
 /******************************************************************************\
- * Copyright (c) 2020-2022
+ * Copyright (c) 2020-2024
  *
  * Author(s):
  *  pljones
@@ -41,7 +41,7 @@ using namespace recorder;
  * Creates a file for the raw PCM data and sets up a QDataStream to which to write received frames.
  * The data is stored Little Endian.
  */
-CJamClient::CJamClient ( const qint64 frame, const int _numChannels, const QString name, const CHostAddress address, const QDir recordBaseDir ) :
+CJamClient::CJamClient ( const qint64 frame, const int _numChannels, const QString name, const CHostAddress& address, const QDir recordBaseDir ) :
     startFrame ( frame ),
     numChannels ( static_cast<uint16_t> ( _numChannels ) ),
     name ( name ),
