@@ -1,5 +1,5 @@
 /******************************************************************************\
- * Copyright (c) 2004-2022
+ * Copyright (c) 2004-2024
  *
  * Author(s):
  *  Volker Fischer
@@ -37,6 +37,9 @@ CServerDlg::CServerDlg ( CServer* pNServP, CServerSettings* pNSetP, const bool b
 
     setupUi ( this );
 
+    // always start on the main tab
+    tabWidget->setCurrentIndex ( 0 );
+
     // set window title
     setWindowTitle ( tr ( "%1 Server", "%1 is the name of the main application" ).arg ( APP_NAME ) );
 
@@ -57,22 +60,21 @@ CServerDlg::CServerDlg ( CServer* pNServP, CServerSettings* pNSetP, const bool b
     lblDirectoryType->setAccessibleName ( strDirectoryTypeAN );
     cbxDirectoryType->setAccessibleName ( strDirectoryTypeAN );
 
-    QString strDirectoryTypeWT = "<b>" + tr ( "Directory" ) + ":</b> " +
-                                 tr ( "Select '%1' not to register your server with a directory." ).arg ( DirectoryTypeToString ( AT_NONE ) ) +
-                                 "<br>" + tr ( "Select one of the genres to register with that directory." ) + "<br>" +
-                                 tr ( "Or select '%1' and specify a Custom Directory address on the "
-                                      "Options tab to register with a custom directory." )
-                                     .arg ( DirectoryTypeToString ( AT_CUSTOM ) ) +
-                                 "<br><br>" +
-                                 tr ( "For any value except '%1', this server registers "
-                                      "with a directory so that a %2 user can select this server "
-                                      "in the client connect dialog server list when they choose that directory." )
-                                     .arg ( DirectoryTypeToString ( AT_NONE ) )
-                                     .arg ( APP_NAME ) +
-                                 "<br><br>" +
-                                 tr ( "The registration of the server is renewed periodically "
+    QString strDirectoryTypeWT = tr ( "<b>Directory:</b> "
+                                      "Select '%1' not to register your server with a directory.<br>"
+                                      "Or select one of the genres to register with that directory.<br>"
+                                      "Or select '%2' and specify a Custom Directory address on the "
+                                      "Options tab to register with a custom directory.<br><br>"
+                                      "For any value except '%1', this server registers "
+                                      "with a directory so that a %3 user can select this server "
+                                      "in the client connect dialog server list when they choose that directory.<br><br>"
+                                      "The registration of the server is renewed periodically "
                                       "to make sure that all servers in the connect dialog server list are "
-                                      "actually available." );
+                                      "actually available.",
+                                      "%1: directory type NONE; %2: directory type CUSTOM; %3 app name, Jamulus" )
+                                     .arg ( DirectoryTypeToString ( AT_NONE ) )
+                                     .arg ( DirectoryTypeToString ( AT_CUSTOM ) )
+                                     .arg ( APP_NAME );
     lblDirectoryType->setWhatsThis ( strDirectoryTypeWT );
     cbxDirectoryType->setWhatsThis ( strDirectoryTypeWT );
 
@@ -116,10 +118,9 @@ CServerDlg::CServerDlg ( CServer* pNServP, CServerSettings* pNSetP, const bool b
     cbxLocationCountry->setAccessibleName ( tr ( "Combo box for location of this server" ) );
 
     // enable recorder
-    chbEnableRecorder->setAccessibleName ( tr ( "Checkbox to turn on or off server recording" ) );
-    chbEnableRecorder->setWhatsThis ( "<b>" + tr ( "Enable Recorder" ) + ":</b> " +
-                                      tr ( "Checked when the recorder is enabled, otherwise unchecked. "
-                                           "The recorder will run when a session is in progress, if (set up correctly and) enabled." ) );
+    chbJamRecorder->setAccessibleName ( tr ( "Checkbox to turn on or off server recording" ) );
+    chbJamRecorder->setWhatsThis ( "<b>" + tr ( "Jam Recorder" ) + ":</b> " +
+                                   tr ( "When checked, the recorder will run while a session is in progress (if set up correctly)." ) );
 
     // new recording
     pbtNewRecording->setAccessibleName ( tr ( "Request new recording button" ) );
@@ -135,9 +136,9 @@ CServerDlg::CServerDlg ( CServer* pNServP, CServerSettings* pNSetP, const bool b
              "Check the value in the Options tab." ) +
         "</dd>" + "<dt>" + SREC_NOT_ENABLED + "</dt>" + "<dd>"
 #ifdef _WIN32
-        + tr ( "Recording has been switched off by the UI checkbox." )
+        + tr ( "Recording has been switched off by the UI checkbox or JSON-RPC." )
 #else
-        + tr ( "Recording has been switched off, either by the UI checkbox or SIGUSR2 being received." )
+        + tr ( "Recording has been switched off, by the UI checkbox, SIGUSR2 or JSON-RPC." )
 #endif
         + "</dd>" + "<dt>" + SREC_NOT_RECORDING + "</dt>" + "<dd>" + tr ( "There is no one connected to the server to record." ) + "</dd>" + "<dt>" +
         SREC_RECORDING + "</dt>" + "<dd>" + tr ( "The performers are being recorded to the specified session directory." ) + "</dd>" + "</dl>" +
@@ -200,7 +201,7 @@ CServerDlg::CServerDlg ( CServer* pNServP, CServerSettings* pNSetP, const bool b
     edtCustomDirectory->setWhatsThis ( strCustomDirectory );
     edtCustomDirectory->setAccessibleName ( tr ( "Custom Directory line edit" ) );
 
-    // server list persistence file name (directory server only)
+    // server list persistence file name (directory only)
     pbtServerListPersistence->setAccessibleName ( tr ( "Server List Filename dialog push button" ) );
     pbtServerListPersistence->setWhatsThis ( "<b>" + tr ( "Server List Filename" ) + ":</b> " +
                                              tr ( "Click the button to open the dialog that allows the "
@@ -370,11 +371,11 @@ CServerDlg::CServerDlg ( CServer* pNServP, CServerSettings* pNSetP, const bool b
     // update delay panning check box
     if ( pServer->IsDelayPanningEnabled() )
     {
-        chbEnableDelayPanning->setCheckState ( Qt::Checked );
+        chbDelayPanning->setCheckState ( Qt::Checked );
     }
     else
     {
-        chbEnableDelayPanning->setCheckState ( Qt::Unchecked );
+        chbDelayPanning->setCheckState ( Qt::Unchecked );
     }
 
     // prepare update check info label (invisible by default)
@@ -410,11 +411,11 @@ CServerDlg::CServerDlg ( CServer* pNServP, CServerSettings* pNSetP, const bool b
 
     // Connections -------------------------------------------------------------
     // check boxes
-    QObject::connect ( chbEnableRecorder, &QCheckBox::stateChanged, this, &CServerDlg::OnEnableRecorderStateChanged );
+    QObject::connect ( chbJamRecorder, &QCheckBox::stateChanged, this, &CServerDlg::OnEnableRecorderStateChanged );
 
     QObject::connect ( chbStartOnOSStart, &QCheckBox::stateChanged, this, &CServerDlg::OnStartOnOSStartStateChanged );
 
-    QObject::connect ( chbEnableDelayPanning, &QCheckBox::stateChanged, this, &CServerDlg::OnEnableDelayPanningStateChanged );
+    QObject::connect ( chbDelayPanning, &QCheckBox::stateChanged, this, &CServerDlg::OnEnableDelayPanningStateChanged );
 
     // line edits
     QObject::connect ( edtServerName, &QLineEdit::editingFinished, this, &CServerDlg::OnServerNameEditingFinished );
@@ -597,11 +598,9 @@ void CServerDlg::OnStopRecorder()
 void CServerDlg::OnRecordingDirClicked()
 {
     // get the current value from pServer
-    QString currentValue    = pServer->GetRecordingDir();
-    QString newRecordingDir = QFileDialog::getExistingDirectory ( this,
-                                                                  tr ( "Select Main Recording Directory" ),
-                                                                  currentValue,
-                                                                  QFileDialog::ShowDirsOnly | QFileDialog::DontUseNativeDialog );
+    QString currentValue = pServer->GetRecordingDir();
+    QString newRecordingDir =
+        QFileDialog::getExistingDirectory ( this, tr ( "Select Main Recording Directory" ), currentValue, QFileDialog::ShowDirsOnly );
 
     if ( newRecordingDir != currentValue )
     {
@@ -625,7 +624,7 @@ void CServerDlg::OnServerListPersistenceClicked()
     QString     currentValue = pServer->GetServerListFileName();
     QFileDialog fileDialog;
     fileDialog.setAcceptMode ( QFileDialog::AcceptSave );
-    fileDialog.setOptions ( QFileDialog::DontUseNativeDialog | QFileDialog::HideNameFilterDetails );
+    fileDialog.setOptions ( QFileDialog::HideNameFilterDetails );
     fileDialog.selectFile ( currentValue );
     if ( fileDialog.exec() && fileDialog.selectedFiles().size() == 1 )
     {
@@ -682,14 +681,15 @@ void CServerDlg::OnCLVersionAndOSReceived ( CHostAddress, COSUtil::EOpSystemType
 
 void CServerDlg::OnTimer()
 {
-    CVector<CHostAddress> vecHostAddresses;
-    CVector<QString>      vecsName;
-    CVector<int>          veciJitBufNumFrames;
-    CVector<int>          veciNetwFrameSizeFact;
+    CVector<CHostAddress>     vecHostAddresses;
+    CVector<QString>          vecsName;
+    CVector<int>              veciJitBufNumFrames;
+    CVector<int>              veciNetwFrameSizeFact;
+    CVector<CChannelCoreInfo> vecChanInfo;
 
     ListViewMutex.lock();
     {
-        pServer->GetConCliParam ( vecHostAddresses, vecsName, veciJitBufNumFrames, veciNetwFrameSizeFact );
+        pServer->GetConCliParam ( vecHostAddresses, vecsName, veciJitBufNumFrames, veciNetwFrameSizeFact, vecChanInfo );
 
         // we assume that all vectors have the same length
         const int iNumChannels = vecHostAddresses.Size();
@@ -732,7 +732,7 @@ void CServerDlg::UpdateGUIDependencies()
     QString             strStatus     = svrRegStatusToString ( eSvrRegStatus );
     QString             strFontColour = "darkGreen";
 
-    if ( pServer->IsDirectoryServer() )
+    if ( pServer->IsDirectory() )
     {
         strStatus = tr ( "Now a directory" );
     }
@@ -766,7 +766,7 @@ void CServerDlg::UpdateGUIDependencies()
     edtLocationCity->setText ( pServer->GetServerCity() );
     cbxLocationCountry->setCurrentIndex ( cbxLocationCountry->findData ( static_cast<int> ( pServer->GetServerCountry() ) ) );
 
-    tedWelcomeMessage->setText ( pServer->GetWelcomeMessage() );
+    tedWelcomeMessage->setPlainText ( pServer->GetWelcomeMessage() );
 
     edtCustomDirectory->setText ( pServer->GetDirectoryAddress() );
 
@@ -836,7 +836,7 @@ void CServerDlg::UpdateRecorderStatus ( QString sessionDir )
     if ( pServer->GetRecorderInitialised() )
     {
         strRecordingDir = pServer->GetRecordingDir();
-        chbEnableRecorder->setEnabled ( true );
+        chbJamRecorder->setEnabled ( true );
 
         if ( pServer->GetRecordingEnabled() )
         {
@@ -870,13 +870,13 @@ void CServerDlg::UpdateRecorderStatus ( QString sessionDir )
             strRecordingDir = tr ( "ERROR" ) + ": " + strRecordingDir;
         }
 
-        chbEnableRecorder->setEnabled ( false );
+        chbJamRecorder->setEnabled ( false );
         strRecorderStatus = SREC_NOT_INITIALISED;
     }
 
-    chbEnableRecorder->blockSignals ( true );
-    chbEnableRecorder->setChecked ( strRecorderStatus != SREC_NOT_ENABLED );
-    chbEnableRecorder->blockSignals ( false );
+    chbJamRecorder->blockSignals ( true );
+    chbJamRecorder->setChecked ( strRecorderStatus != SREC_NOT_ENABLED );
+    chbJamRecorder->blockSignals ( false );
 
     edtRecordingDir->setText ( strRecordingDir );
     edtRecordingDir->setEnabled ( !bIsRecording );
