@@ -1,5 +1,5 @@
 /******************************************************************************\
- * Copyright (c) 2004-2022
+ * Copyright (c) 2004-2024
  *
  * Author(s):
  *  Volker Fischer
@@ -133,7 +133,7 @@ CServerListManager::CServerListManager ( const quint16  iNPortNum,
     bEnableIPv6 ( bNEnableIPv6 ),
     ServerListFileName ( strServerListFileName ),
     strDirectoryAddress ( "" ),
-    bIsDirectoryServer ( false ),
+    bIsDirectory ( false ),
     eSvrRegStatus ( SRS_NOT_REGISTERED ),
     strMinServerVersion ( "" ), // disable version check with empty version
     pConnLessProtocol ( pNConLProt ),
@@ -184,12 +184,13 @@ CServerListManager::CServerListManager ( const quint16  iNPortNum,
     /*
      * Init server list entry (server info for this server) with defaults.
      *
-     * The client will use the built in or custom address when retrieving the server list from a directory.
      * The values supplied here only apply when using the server as a server, not as a directory.
+     * Note that the client will use the directory address (i.e. the address the server list was returned from)
+     * when connecting to a directory as a server.
      *
      * If we are a directory, we assume that we are a permanent server.
      */
-    CServerListEntry ThisServerListEntry ( haServerAddr, ServerPublicIP, "", QLocale::system().country(), "", iNumChannels, bIsDirectoryServer );
+    CServerListEntry ThisServerListEntry ( haServerAddr, ServerPublicIP, "", QLocale::system().country(), "", iNumChannels, bIsDirectory );
 
     // parse the server info string according to definition:
     // [this server name];[this server city];[this server country as QLocale ID] (; ... ignored)
@@ -232,10 +233,6 @@ CServerListManager::CServerListManager ( const quint16  iNPortNum,
                                         .arg ( slServInfoSeparateParams[2] )
                                         .arg ( QLocale::countryToString ( ThisServerListEntry.eCountry ) ) );
     }
-    else
-    {
-        qWarning() << "Ignoring invalid serverinfo, please verify the parameter syntax.";
-    }
 
     // per definition, the very first entry is this server and this entry will
     // never be deleted
@@ -247,7 +244,7 @@ CServerListManager::CServerListManager ( const quint16  iNPortNum,
     // set the directory address - not the type, that gets done by app start up
     SetDirectoryAddress ( sNDirectoryAddress );
 
-    // whitelist parsing - only used when bIsDirectoryServer
+    // whitelist parsing - only used when bIsDirectory
     if ( !strServerListFilter.isEmpty() )
     {
         // split the different parameter strings
@@ -365,7 +362,7 @@ void CServerListManager::SetDirectoryAddress ( const QString sNDirectoryAddress
     // now save the new name
     strDirectoryAddress = sNDirectoryAddress;
 
-    SetIsDirectoryServer();
+    SetIsDirectory();
 
     locker.unlock();
 
@@ -389,7 +386,7 @@ void CServerListManager::SetDirectoryType ( const EDirectoryType eNCSAT )
     // now update the server type
     DirectoryType = eNCSAT;
 
-    SetIsDirectoryServer();
+    SetIsDirectory();
 
     locker.unlock();
 
@@ -397,31 +394,31 @@ void CServerListManager::SetDirectoryType ( const EDirectoryType eNCSAT )
     Register();
 }
 
-void CServerListManager::SetIsDirectoryServer()
+void CServerListManager::SetIsDirectory()
 {
     // this is called with the lock set
 
     // per definition: If we are registered and the directory
-    // is the localhost address, we are in directory server mode.
-    bool bNIsDirectoryServer = DirectoryType == AT_CUSTOM &&
-                               ( !strDirectoryAddress.compare ( "localhost", Qt::CaseInsensitive ) || !strDirectoryAddress.compare ( "127.0.0.1" ) );
+    // is the localhost address, we are in directory mode.
+    bool bNIsDirectory = DirectoryType == AT_CUSTOM &&
+                         ( !strDirectoryAddress.compare ( "localhost", Qt::CaseInsensitive ) || !strDirectoryAddress.compare ( "127.0.0.1" ) );
 
-    if ( bIsDirectoryServer == bNIsDirectoryServer )
+    if ( bIsDirectory == bNIsDirectory )
     {
         return;
     }
 
-    bIsDirectoryServer = bNIsDirectoryServer;
+    bIsDirectory = bNIsDirectory;
 
-    if ( bIsDirectoryServer )
+    if ( bIsDirectory )
     {
-        qInfo() << "Now a directory";
+        qInfo() << qUtf8Printable ( tr ( "Now a directory" ) );
         // Load any persistent server list (create it if it is not there)
         (void) Load();
     }
     else
     {
-        qInfo() << "No longer a directory server";
+        qInfo() << qUtf8Printable ( tr ( "No longer a directory" ) );
     }
 }
 
@@ -441,7 +438,7 @@ void CServerListManager::Unregister()
     QMutexLocker locker ( &Mutex );
 
     // disable service -> stop timer
-    if ( bIsDirectoryServer )
+    if ( bIsDirectory )
     {
         TimerPollList.stop();
         TimerPingServerInList.stop();
@@ -473,7 +470,7 @@ void CServerListManager::Register()
     // this is called without the lock set
     QMutexLocker locker ( &Mutex );
 
-    if ( bIsDirectoryServer )
+    if ( bIsDirectory )
     {
         // start timer for polling the server list if enabled
         // 1 minute = 60 * 1000 ms
@@ -494,15 +491,15 @@ void CServerListManager::Register()
         // in OnTimerCLRegisterServerResp on failure
         TimerCLRegisterServerResp.start();
 
-        // start timer for registering this server at the directory server
+        // start timer for registering this server at the directory
         // 1 minute = 60 * 1000 ms
         TimerRefreshRegistration.start ( SERVLIST_REGIST_INTERV_MINUTES * 60000 );
 
-        // Start timer for ping the directory server in short intervals to
+        // Start timer for ping the directory in short intervals to
         // keep the port open at the NAT router.
         // If no NAT is used, we send the messages anyway since they do
         // not hurt (very low traffic). We also reuse the same update
-        // time as used in the directory server for pinging the registered
+        // time as used in the directory for pinging the registered
         // servers.
         TimerPingServers.start ( SERVLIST_UPDATE_PING_SERVERS_MS );
 
@@ -512,7 +509,7 @@ void CServerListManager::Register()
     }
 }
 
-/* Directory server list functionality ****************************************/
+/* Server list functionality **************************************************/
 void CServerListManager::OnTimerPingServerInList()
 {
     QMutexLocker locker ( &Mutex );
@@ -534,7 +531,7 @@ void CServerListManager::OnTimerPollList()
 
     QMutexLocker locker ( &Mutex );
 
-    // Check all list entries are still valid (omitting the directory server itself)
+    // Check all list entries are still valid (omitting the directory itself)
     for ( int iIdx = ServerList.size() - 1; iIdx > 0; iIdx-- )
     {
         // 1 minute = 60 * 1000 ms
@@ -559,7 +556,7 @@ void CServerListManager::Append ( const CHostAddress&    InetAddr,
                                   const CServerCoreInfo& ServerInfo,
                                   const QString          strVersion )
 {
-    if ( bIsDirectoryServer )
+    if ( bIsDirectory )
     {
         // if the client IP address is a private one, it's on the same LAN as the directory
         bool serverIsExternal = !NetworkUtil::IsPrivateNetworkIP ( InetAddr.InetAddr );
@@ -601,7 +598,7 @@ void CServerListManager::Append ( const CHostAddress&    InetAddr,
 
         // Check if server is already registered.
         // The very first list entry must not be checked since
-        // this is per definition the directory server (i.e., this server)
+        // this is per definition the directory (i.e., this server)
         int iSelIdx = IndexOf ( InetAddr );
 
         // if server is not yet registered, we have to create a new entry
@@ -636,14 +633,14 @@ void CServerListManager::Append ( const CHostAddress&    InetAddr,
 
 void CServerListManager::Remove ( const CHostAddress& InetAddr )
 {
-    if ( bIsDirectoryServer )
+    if ( bIsDirectory )
     {
         qInfo() << qUtf8Printable ( QString ( "Requested to unregister entry for %1" ).arg ( InetAddr.toString() ) );
 
         QMutexLocker locker ( &Mutex );
 
         // Find the server to unregister in the list. The very first list entry
-        // must not be removed since this is per definition the directory server
+        // must not be removed since this is per definition the directory
         // (i.e., this server).
         int iIdx = IndexOf ( InetAddr );
         if ( iIdx > 0 )
@@ -670,7 +667,7 @@ void CServerListManager::RetrieveAll ( const CHostAddress& InetAddr )
 {
     QMutexLocker locker ( &Mutex );
 
-    if ( bIsDirectoryServer )
+    if ( bIsDirectory )
     {
         // if the client IP address is a private one, it's on the same LAN as the directory
         bool clientIsInternal = NetworkUtil::IsPrivateNetworkIP ( InetAddr.InetAddr );
@@ -730,12 +727,12 @@ void CServerListManager::RetrieveAll ( const CHostAddress& InetAddr )
     }
 }
 
-int CServerListManager::IndexOf ( CHostAddress haSearchTerm )
+int CServerListManager::IndexOf ( const CHostAddress& haSearchTerm )
 {
     // Called with lock set.
 
     // Find the server in the list. The very first list entry
-    // per definition is the directory server
+    // per definition is the directory
     // (i.e., this server).
     for ( int iIdx = ServerList.size() - 1; iIdx > 0; iIdx-- )
     {
@@ -770,7 +767,7 @@ bool CServerListManager::Load()
 {
     // this is called with the lock set
 
-    if ( !bIsDirectoryServer || ServerListFileName.isEmpty() )
+    if ( !bIsDirectory || ServerListFileName.isEmpty() )
     {
         // this gets called again if either of the above change
         return true;
@@ -780,14 +777,14 @@ bool CServerListManager::Load()
 
     if ( !file.open ( QIODevice::ReadWrite | QIODevice::Text ) )
     {
-        qWarning() << qUtf8Printable (
-            QString ( "Could not open '%1' for read/write.  Please check that %2 has permission (and that there is free space)." )
-                .arg ( ServerListFileName )
-                .arg ( APP_NAME ) );
+        qWarning() << qUtf8Printable ( QString ( tr ( "Could not open '%1' for read/write. "
+                                                      "Please check that %2 has permission (and that there is free space)." ) )
+                                           .arg ( ServerListFileName )
+                                           .arg ( APP_NAME ) );
         ServerListFileName.clear();
         return false;
     }
-    qInfo() << "Loading persistent server list file:" << ServerListFileName;
+    qInfo() << qUtf8Printable ( QString ( tr ( "Loading persistent server list file: %1" ) ).arg ( ServerListFileName ) );
 
     // do not lose our entry
     CServerListEntry serverListEntry = ServerList[0];
@@ -850,7 +847,7 @@ void CServerListManager::Save()
     if ( !file.open ( QIODevice::WriteOnly | QIODevice::Truncate | QIODevice::Text ) )
     {
         // Not a useable file
-        qWarning() << QString ( tr ( "Could not write to '%1'" ) ).arg ( ServerListFileName );
+        qWarning() << qUtf8Printable ( QString ( tr ( "Could not write to '%1'" ) ).arg ( ServerListFileName ) );
         ServerListFileName.clear();
 
         return;
@@ -861,7 +858,7 @@ void CServerListManager::Save()
     // (that's this server, which is added automatically on start up, not read)
     for ( int iIdx = ServerList.size() - 1; iIdx > 0; iIdx-- )
     {
-        qInfo() << qUtf8Printable ( QString ( "Saving registration for %1 (%2): %3" )
+        qInfo() << qUtf8Printable ( QString ( tr ( "Saving registration for %1 (%2): %3" ) )
                                         .arg ( ServerList[iIdx].HostAddr.toString() )
                                         .arg ( ServerList[iIdx].LHostAddr.toString() )
                                         .arg ( ServerList[iIdx].strName ) );
@@ -910,8 +907,8 @@ void CServerListManager::OnTimerPingServers()
     // first check if directory address is valid
     if ( !( DirectoryAddress == CHostAddress() ) )
     {
-        // send empty message to directory server to keep NAT port open -> we do
-        // not require any answer from the directory server
+        // send empty message to directory to keep NAT port open -> we do
+        // not require any answer from the directory
         pConnLessProtocol->CreateCLEmptyMes ( DirectoryAddress );
     }
 }
@@ -965,7 +962,7 @@ void CServerListManager::SetRegistered ( const bool bIsRegister )
         return;
     }
 
-    if ( bIsDirectoryServer )
+    if ( bIsDirectory )
     {
         // this IS the directory, no network message to worry about
         SetSvrRegStatus ( bIsRegister ? SRS_REGISTERED : SRS_NOT_REGISTERED );
